==> libreoffice-7.3.7.2.tar.xz: libreoffice-7.3.7.2/ridljar/test/com/sun/star/lib/uno/environments/remote/TestWorkAt.java <==
/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

package com.sun.star.lib.uno.environments.remote;

import static org.junit.Assert.*;

class TestWorkAt implements TestIWorkAt {
    /**
     * When set to true, enables various debugging output.
     */
    private static final boolean DEBUG = false;

    static final int MESSAGES = 35;


    int _counter;

    int _sync_counter;
    int _async_counter;

    private boolean _passedAsync = true;
    boolean _notified = false;

    public synchronized void syncCall() throws Throwable {
        ++ _sync_counter;

        // at least in currently run tests this should never fire, so don't
        // defer the check until passedAsyncTest and assert here
        assertEquals(MESSAGES, _async_counter);
        if(_async_counter != MESSAGES)
            _passedAsync = false;

        if(DEBUG) System.err.println("syncCall:" + _sync_counter + " " + _passedAsync + " " + Thread.currentThread());
    }

    public synchronized void asyncCall() throws Throwable {
        ++ _async_counter;

        if(DEBUG) System.err.println("asyncCall:" + _async_counter + " " + Thread.currentThread());
    }

    public synchronized void increment() throws Throwable {
        if(DEBUG) System.err.println("increment - " + Thread.currentThread());

        ++ _counter;
        notifyAll();
    }

    public synchronized void notifyme() {
        if(DEBUG) System.err.println("\t\t\tnotifying me" + Thread.currentThread());

        notifyAll();

        _notified = true;
    }

    public synchronized boolean passedAsyncTest() {
        assertEquals(MESSAGES, _sync_counter);
        assertTrue(_passedAsync);
        return  _passedAsync && (_sync_counter == MESSAGES);
    }
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_25.8.3.orig.tar.xz: libreoffice-25.8.3.2/ridljar/test/com/sun/star/lib/uno/environments/remote/TestWorkAt.java <==
/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

package com.sun.star.lib.uno.environments.remote;

import static org.junit.Assert.*;

class TestWorkAt implements TestIWorkAt {
    /**
     * When set to true, enables various debugging output.
     */
    private static final boolean DEBUG = false;

    static final int MESSAGES = 35;


    int _counter;

    int _sync_counter;
    int _async_counter;

    private boolean _passedAsync = true;
    private boolean _notified = false;

    public synchronized void syncCall() throws Throwable {
        ++ _sync_counter;

        // at least in currently run tests this should never fire, so don't
        // defer the check until passedAsyncTest and assert here
        assertEquals(MESSAGES, _async_counter);
        if(_async_counter != MESSAGES)
            _passedAsync = false;

        if(DEBUG) System.err.println("syncCall:" + _sync_counter + " " + _passedAsync + " " + Thread.currentThread());
    }

    public synchronized void asyncCall() throws Throwable {
        ++ _async_counter;

        if(DEBUG) System.err.println("asyncCall:" + _async_counter + " " + Thread.currentThread());
    }

    public synchronized void increment() throws Throwable {
        if(DEBUG) System.err.println("increment - " + Thread.currentThread());

        ++ _counter;
        notifyAll();
    }

    public synchronized void notifyme() {
        if(DEBUG) System.err.println("\t\t\tnotifying me" + Thread.currentThread());

        notifyAll();

        _notified = true;
    }

    public synchronized boolean isNotified() {
        return _notified;
    }

    public synchronized boolean passedAsyncTest() {
        assertEquals(MESSAGES, _sync_counter);
        assertTrue(_passedAsync);
        return  _passedAsync && (_sync_counter == MESSAGES);
    }
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
